/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { ApiRootLinkRel, ApiRootResource, ApiRootService } from '@alfa-client/api-root-shared';
import { BuildInfoComponent } from '@alfa-client/common';
import { Environment, getEnvironmentFactory } from '@alfa-client/environment-shared';
import { StateResource, TechSharedModule } from '@alfa-client/tech-shared';
import { CommonModule } from '@angular/common';
import { Component, OnInit } from '@angular/core';
import { ActivatedRoute, Params, Router, RouterOutlet } from '@angular/router';
import {
  AdminLogoIconComponent,
  MailboxIconComponent,
  NavbarComponent,
  NavItemComponent,
  OrgaUnitIconComponent,
  UsersIconComponent,
} from '@ods/system';
import { AuthenticationService } from 'libs/authentication/src/lib/authentication.service';
import { Observable } from 'rxjs';
import { UserProfileButtonContainerComponent } from '../common/user-profile-button-container/user-profile.button-container.component';
import { UnavailablePageComponent } from '../pages/unavailable/unavailable-page/unavailable-page.component';

@Component({
  selector: 'app-root',
  templateUrl: './app.component.html',
  styleUrls: ['./app.component.scss'],
  standalone: true,
  imports: [
    CommonModule,
    NavbarComponent,
    NavItemComponent,
    UsersIconComponent,
    UserProfileButtonContainerComponent,
    AdminLogoIconComponent,
    MailboxIconComponent,
    OrgaUnitIconComponent,
    RouterOutlet,
    UnavailablePageComponent,
    BuildInfoComponent,
    TechSharedModule,
  ],
})
export class AppComponent implements OnInit {
  readonly title = 'admin';

  public apiRootStateResource$: Observable<StateResource<ApiRootResource>>;
  public readonly environment: Environment = getEnvironmentFactory();

  public readonly apiRootLinkRel = ApiRootLinkRel;

  constructor(
    public authenticationService: AuthenticationService,
    private apiRootService: ApiRootService,
    private router: Router,
    private route: ActivatedRoute,
  ) {}

  ngOnInit(): void {
    this.authenticationService.login().then(() => this.doAfterLoggedIn());
  }

  doAfterLoggedIn(): void {
    this.apiRootStateResource$ = this.apiRootService.getApiRoot();
    this.forwardWithoutAuthenticationParams();
  }

  forwardWithoutAuthenticationParams() {
    const queryParams = this.getQueryParamsWithoutAuthentication();
    this.router.navigate([], { queryParams });
  }

  private getQueryParamsWithoutAuthentication(): Params {
    const { iss, state, session_state, code, ...queryParams } = this.route.snapshot.queryParams;
    return queryParams;
  }
}
