/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { OrganisationsEinheitFormContainerComponent } from '@admin-client/organisations-einheit';
import { ApiRootLinkRel, ApiRootResource, ApiRootService } from '@alfa-client/api-root-shared';
import { createStateResource, StateResource, TechSharedModule } from '@alfa-client/tech-shared';
import { existsAsHtmlElement, mock, Mock, notExistsAsHtmlElement } from '@alfa-client/test-utils';
import { CommonModule } from '@angular/common';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { createApiRootResource } from 'libs/api-root-shared/test/api-root';
import { getDataTestIdOf } from 'libs/tech-shared/test/data-test';
import { singleColdCompleted } from 'libs/tech-shared/test/marbles';
import { MockComponent } from 'ng-mocks';
import { Observable, of } from 'rxjs';
import { OrganisationsEinheitFormPageComponent } from './organisationseinheit-form-page.component';

describe('OrganisationsEinheitFormPageComponent', () => {
  let component: OrganisationsEinheitFormPageComponent;
  let fixture: ComponentFixture<OrganisationsEinheitFormPageComponent>;

  const organisationsEinheitFormSelector: string = getDataTestIdOf('organisations-einheit-form');

  let apiRootService: Mock<ApiRootService>;

  beforeEach(async () => {
    apiRootService = mock(ApiRootService);

    await TestBed.configureTestingModule({
      imports: [CommonModule, TechSharedModule],
      declarations: [OrganisationsEinheitFormPageComponent, MockComponent(OrganisationsEinheitFormContainerComponent)],
      providers: [{ provide: ApiRootService, useValue: apiRootService }],
    }).compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(OrganisationsEinheitFormPageComponent);
    component = fixture.componentInstance;

    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('component', () => {
    describe('ngOnInit', () => {
      const apiRootStateResource: StateResource<ApiRootResource> = createStateResource(createApiRootResource());
      const apiRootStateResource$: Observable<StateResource<ApiRootResource>> = of(apiRootStateResource);

      beforeEach(() => {
        apiRootService.getApiRoot.mockReturnValue(apiRootStateResource$);
      });

      it('should call apiRootService getApiRoot', () => {
        component.ngOnInit();

        expect(apiRootService.getApiRoot).toHaveBeenCalled();
      });

      it('should get apiRootStateResource$', () => {
        component.ngOnInit();

        expect(component.apiRootStateResource$).toBeObservable(singleColdCompleted(apiRootStateResource));
      });
    });
  });

  describe('template', () => {
    describe('admin-organisationseinheit-form-container', () => {
      it('should be rendered if apiRootState has link', () => {
        component.apiRootStateResource$ = of(createStateResource(createApiRootResource([ApiRootLinkRel.ORGANISATIONS_EINHEIT])));
        fixture.detectChanges();

        existsAsHtmlElement(fixture, organisationsEinheitFormSelector);
      });

      it('should not be rendered if apiRootState has no link', () => {
        component.apiRootStateResource$ = of(createStateResource(createApiRootResource()));
        fixture.detectChanges();

        notExistsAsHtmlElement(fixture, organisationsEinheitFormSelector);
      });
    });
  });
});
