/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import {
  AdminOrganisationsEinheitResource,
  AdminOrganisationsEinheitSyncResult,
} from '@admin-client/organisations-einheit-shared';
import { TechSharedModule } from '@alfa-client/tech-shared';
import { CommonModule } from '@angular/common';
import { Component, Input } from '@angular/core';
import { MatTooltip } from '@angular/material/tooltip';
import { ExclamationIconComponent, ListComponent, ListItemComponent } from '@ods/system';

@Component({
  selector: 'admin-organisations-einheit-list',
  templateUrl: './organisations-einheit-list.component.html',
  standalone: true,
  imports: [CommonModule, ListComponent, ListItemComponent, ExclamationIconComponent, MatTooltip, TechSharedModule],
})
export class OrganisationsEinheitListComponent {
  private _organisationsEinheitResources: AdminOrganisationsEinheitResource[] = [];

  @Input()
  public get organisationsEinheitResources(): AdminOrganisationsEinheitResource[] {
    return this._organisationsEinheitResources;
  }

  public set organisationsEinheitResources(list: AdminOrganisationsEinheitResource[]) {
    this.moveChildrenIntoParentLevel(list);
  }

  public readonly AdminOrganisationsEinheitSyncResult = AdminOrganisationsEinheitSyncResult;

  moveChildrenIntoParentLevel(list: AdminOrganisationsEinheitResource[]): void {
    list.forEach((parent: AdminOrganisationsEinheitResource) => {
      this._organisationsEinheitResources.push(parent);

      if (parent._embedded && Array.isArray(parent._embedded.childList)) {
        parent._embedded.childList.forEach((child: AdminOrganisationsEinheitResource) => {
          child.isChild = true;
          this._organisationsEinheitResources.push(child);
        });
      }
    });
  }
}
