/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { mock, Mock, useFromMock } from '@alfa-client/test-utils';
import { fakeAsync, tick } from '@angular/core/testing';
import { of } from 'rxjs';
import { createUser } from '../../test/user';
import { User } from './user.model';
import { UserRepository } from './user.repository.service';
import { UserService } from './user.service';
import * as UserUtil from './user.util';

describe('UserService', () => {
  let service: UserService;
  let repository: Mock<UserRepository>;

  const user: User = createUser();

  beforeEach(() => {
    repository = { ...mock(UserRepository), getUsers: jest.fn().mockReturnValue(of([user])) };
    service = new UserService(useFromMock(repository));
  });

  describe('getItemsFromKeycloak', () => {
    it('should call getUsers from userRepository', () => {
      service.getItemsFromKeycloak();

      expect(repository.getUsers).toHaveBeenCalled();
    });

    it('should call sortUsersByLastName', fakeAsync(() => {
      const sortUsersByLastNameSpy: jest.SpyInstance<User[]> = jest.spyOn(UserUtil, 'sortUsersByLastName');

      service.getItemsFromKeycloak().subscribe();
      tick();

      expect(sortUsersByLastNameSpy).toHaveBeenCalled();
    }));
  });
});
