/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { ROUTES } from '@admin-client/shared';
import { createStateResource } from '@alfa-client/tech-shared';
import { Mock, mock } from '@alfa-client/test-utils';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { Router } from '@angular/router';
import { ButtonWithSpinnerComponent } from '@ods/component';
import { MailboxIconComponent, PersonIconComponent } from '@ods/system';
import { ToUserNamePipe } from 'libs/admin/user-shared/src/lib/to-user-name.pipe';
import { UserService } from 'libs/admin/user-shared/src/lib/user.service';
import { createUser } from 'libs/admin/user-shared/test/user';
import { MockComponent, MockPipe } from 'ng-mocks';
import { UsersRolesComponent } from './users-roles.component';

describe('UsersRolesComponent', () => {
  let component: UsersRolesComponent;
  let fixture: ComponentFixture<UsersRolesComponent>;
  let router: Router;

  const userService: Mock<UserService> = {
    ...mock(UserService),
    get: jest.fn(),
  };

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      providers: [{ provide: UserService, useValue: userService }],
      imports: [
        MockComponent(ButtonWithSpinnerComponent),
        MockComponent(MailboxIconComponent),
        MockComponent(PersonIconComponent),
        MockPipe(ToUserNamePipe),
        UsersRolesComponent,
      ],
    }).compileComponents();

    TestBed.inject(UserService);
    router = TestBed.inject(Router);

    fixture = TestBed.createComponent(UsersRolesComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  describe('component', () => {
    describe('ngOnInit', () => {
      it('should get users from userService', () => {
        const userState = createStateResource([createUser()]);
        userService.get.mockReturnValueOnce(userState);

        component.ngOnInit();

        expect(component.users$).toBe(userState);
      });
    });

    describe('navigateToAddUser', () => {
      it('should navigate to add user', () => {
        const routerSpy = jest.spyOn(router as any, 'navigate');

        component.navigateToAddUser();

        expect(routerSpy).toHaveBeenCalledWith([ROUTES.BENUTZER_UND_ROLLEN_NEU]);
      });
    });
  });

  describe('template', () => {
    it('should create', () => {
      expect(component).toBeTruthy();
    });

    describe('constructor', () => {
      it('should call userService.get', () => {
        expect(userService.get).toHaveBeenCalled();
      });
    });
  });
});
